@@ -24,8 +24,7 @@ import json
 from json import JSONDecodeError
 
 import hop
-from hop import Stream, list_topics
-from hop import auth
+from hop import Stream, list_topics  # noqa: F401
 from hop.auth import Auth
 
 import warnings
