@@ -37,13 +37,15 @@ def parser():
     parser.add_argument('-s', '--server', default=DEFAULT_SERVER,
                         help='igwn-alert server hostname')
     parser.add_argument('-u', '--username',
-                        help='User name (default: look up in auth.toml or .netrc)')
+                        help='User name (default: look up in auth.toml '
+                              'or .netrc)')
 
     subparsers = parser.add_subparsers(dest='action', help='sub-command help')
     subparsers.required = True
 
     subparser = subparsers.add_parser(
-        'listen', help='Listen for igwn-alert messages and print them to stdout.')
+        'listen', help='Listen for igwn-alert messages and print '
+                       'them to stdout.')
     subparser.add_argument(
         'topics', nargs='*', help='a pubsub topic or list of topics '
                                   '(e.g. cbc_gstlal)')
@@ -80,7 +82,7 @@ def main(args=None):
         if opts.action == 'listen':
             lv.listen(callback=None, topic=[*opts.topics])
         if opts.action == 'topics':
-            print("Topics for group {0} associated with the current " \
+            print("Topics for group {0} associated with the current "
                   "credential:".format(opts.group))
             print(*lv.get_topics(), sep='\n')
         elif opts.action == 'subscriptions':
@@ -98,9 +100,9 @@ def main(args=None):
                 eventfile = openfile.read().decode('utf-8')
                 try:
                     alert = json.dumps(eventfile)
-                except:
-                    alert=eventfile
-                lv.publish(topic=opts.topic, msg=eventfile)
+                except Exception:
+                    alert = eventfile
+                lv.publish(topic=opts.topic, msg=alert)
                 openfile.close()
     except (KeyboardInterrupt, SystemExit):
         pass
